$fn=100;

include<bearingmod.scad>; // modded to add other models (625, 6000), and local include
include<motorsmod.scad>; // modded for local include
include<hobbedgear.scad>; // default 11 x 9 MK8
include<OBtee-nut.scad>; // for openbuilds tee-nut and subtractive blank
use<ISOthread.scad>; // for making screws, nuts, and screw holes

module pressfit(){
thread_out_centre(5,3);				// make a centre for an M5 x 3 ISO thread
thread_out_pitch(5,3,0.8);			// make an M5 x 3 thread with 0.8 mm pitch
translate([0,0,3])
cylinder(h=4.32,r=7.1/2);
translate([0,0,7.32])
cylinder(h=9.14,r=7.9/2);
translate([0,0,16.46])
cylinder(h=0.5,r=5.0/2);
translate([0,0,16.96])
cylinder(h=1.5,r=7.9/2);
}

module pressfitdiff(){
union(){
thread_out_centre(5,3);				// make a centre for an M5 x 3 ISO thread
thread_out_pitch(5,3,0.8);			// make an M5 x 3 thread with 0.8 mm pitch
translate([0,0,3])
cylinder(h=4.32,r=7.1/2);
}
}

module barrelwscrew(){
cylinder(h=12, r=8.0/2);
  translate([33,0,6]) // safe screw movement range 30-34 (or 35)
rotate([0,-90,0])
hex_bolt(4,30);
} 

module barrelnutprint(){ // substitute a printed barrel with inserted nut
difference(){
cylinder(h=12, r=8.0/2);
translate([5,0,6])
rotate([0,-90,0])
#cylinder(h=10,r=4.1/2);
translate([-3.1/2,-5,6-7.1/2])
#cube([3.1,10,7.1]);
} 
}



module thumbspring(){
difference(){
  union(){
    cylinder(h=5,r1=4,r2=5.5);
    translate([0,0,5])
    cylinder(h=4.5,r=5.5);
    
    translate([0,0,8.5])
    cylinder(h=2.5,r1=5.5,r2=8.5);
    translate([0,0,11])
    cylinder(h=5,r=7.75);
    
    translate([0,0,11])
    for(i=[0:20:340]){
      rotate(i)
      translate([7.25,0,0])
      cylinder(h=5,r=1.25);
    }
  }
  translate([0,0,-1])
  cylinder(h=7,r=4.5/2);
  translate([0,0,5])
  cylinder(h=7,r=6.5/2);
  translate([0,0,10])
  cylinder(h=7,r=4.2,$fn=6);
  
  translate([0,0,8.1])
  rotate_extrude(convexity=10)
  translate([8,0,0])
  circle(r=2.5);
}
}


module lever(){ // Note: Entire lever assy will be translated up 0.3mm
difference(){
union(){
hull(){
translate([0,0,4]) // lever pivot
cylinder(h=15.4,r=5.6);
translate([10.2,-6,0]) // sweep to flat "top" of lever
cylinder(h=19.4,r=1);
}
hull(){ // lever
translate([5.2,-40,0])
cube([0.4,41.85,19.4]);
translate([10.2,-6,0])
cylinder(h=19.4,r=1);
translate([8.2,-43.5,0])
cylinder(h=19.4,r=1);
translate([10.2,-41.6,0])
cylinder(h=19.4,r=1);
translate([6.2,-40,0])
cylinder(h=19.4,r=1);

}
hull(){ // bearing plate
translate([5.2,-31,0])
cube([1,30,19.4]);
translate([-3.3,-4.4,0])
cylinder(h=19.4,r=0.2);
translate([-2.2,-15.5,2.7])
//cylinder(h=14,r=5);
teenuthull(14); // shape to hold teenut (on top)
}
}
// axle plate clearance
translate([0,0,0])
cylinder(h=4,r=6);
// axle bolt hole
translate([0,0,3])
cylinder(h=17.4,r=1.6);
// bearing bolt hole
translate([-2.2,-15.5,2])
cylinder(h=16,r=5.1/2);
// bearing plate surfaces
translate([-2.2,-15.5,2.7]) // z is -2.3 for bolt head on bottom
rotate([180,0,0])
teenutblank(); // this puts teenut on bottom
translate([-2.2,-15.5,16.7])
hull(){
cylinder(h=5,r=4.8); // bolt head on top
translate([-5.1,-4.8,0]) // 0.5 clearance around
cube([5.1,9.6,5]);
}
// tail post clearance
translate([0,-31.2,-0.5])
hull(){
cylinder(h=20,r=5.2);
translate([-5.2,-5.2,0])
cube([5.2,10.4,20]);
}
// bearing slot
translate([-2.2,-15.5,6.1])
cylinder(h=7.2,r=9);
// lock slot
translate([12-15.5,-22-15.5,10-0.3])
hull(){
rotate([0,90,0])
cylinder(h=20,r=4.5/2);
rotate([0,90,-45])
cylinder(h=30,r=4.5/2);
}
}
translate([-2.2,-15.5,7.2]) // idler pressure bearing
%bearing(model=625);
}

module base(){
difference(){
union(){
hull(){ // top hull
translate([14.5,20.1,0])
cube([1,1,20]);
translate([11.1,11,0])
cube([1,1,20]);
// upper left corner "bits"
translate([-21.1,11,0])
cube([1,1,20]);
translate([-20.1,17,0])
cylinder(h=20,r=1);
translate([-17,20.1,0])
cylinder(h=20,r=1);
}
translate([15.5,15.5,0])
cylinder(h=5, r=5.6); // upper right cylinder spacer (1 mm too high)

hull(){ // bottom hull
translate([15.5,-15.5,0])
cylinder(h=20, r=4.5);
// barrel post
translate([13,-22,0])
cylinder(h=20,r=7);
// lower left corner "bits"  
translate([-17,-20.1,0])
cylinder(h=20,r=1);
translate([-20.1,-17,0])
cylinder(h=20,r=1);
translate([-21.1,-12,0])
cube([1,1,20]);
}
// side cube
translate([-21.1,-12,0])
cube([8,24,20]);
}

// stepper-screw holes
translate([-15.5,-15.5,-1])
cylinder(h=22, r=1.6);
translate([-15.5,15.5,-1])
cylinder(h=22, r=1.6);
translate([15.5,15.5,-1])
cylinder(h=22, r=1.6);
translate([15.5,-15.5,-1])
cylinder(h=22, r=1.6);

// remove material left side to create radius inside corners
hull(){
 translate([-13.1,7,-1])
 cylinder(h=22,r=4);
 translate([-13.1,-7,-1])
 cylinder(h=22,r=4);
}

// remove material for lever pivot
translate([15.5,15.5,4])
cylinder(h=17, r=6); // gives 0.4 clearance [ make lever pivot r=5.6 ]

// press fit hole
translate([4.4,14,10])
rotate([-90,0,0])
pressfitdiff();

// barrel nut hole
translate([12,-22,3])
cylinder(h=18, r=8.2/2);

// lock slot
translate([12,-22,10])
hull(){
rotate([0,90,0])
cylinder(h=20,r=4.5/2);
rotate([0,90,-45])
cylinder(h=30,r=4.5/2);
}

// filament path
translate([4.4,22,10])
rotate([90,0,0])
cylinder(h=50,r=1.1);
translate([4.4,10.5,10])
rotate([-90,0,0])
cylinder(h=4,r1=2.1,r2=1.1);
translate([4.4,-27.5,10])
rotate([-90,0,0])
cylinder(h=6,r1=2.1,r2=1.1);
  
}
}

module cover(){
difference(){
union(){
hull(){
// lower part
translate([-20.1,17,0])
cylinder(h=5,r=1);
translate([-17,20.1,0])
cylinder(h=5,r=1);
translate([-17,-20.1,0])
cylinder(h=5,r=1);
translate([-20.1,-17,0])
cylinder(h=5,r=1);
translate([13,-22,0])
cylinder(h=5,r=7);
translate([15.5,15.5,0])
cylinder(h=5, r=5.6);
translate([22.7,13.6,0])
cylinder(h=5, r=1);
translate([22.7,-22.1,0])
cylinder(h=5, r=1);
// stepper-shaped part
translate([-18.1,15,0])
cylinder(h=8,r=1);
translate([-15,18.1,0])
cylinder(h=8,r=1);
translate([-15,-18.1,0])
cylinder(h=8,r=1);
translate([-18.1,-15,0])
cylinder(h=8,r=1);
translate([18.1,15,0])
cylinder(h=8,r=1);
translate([15,18.1,0])
cylinder(h=8,r=1);
translate([15,-18.1,0])
cylinder(h=8,r=1);
translate([18.1,-15,0])
cylinder(h=8,r=1);
}
hull(){
translate([0,0,-6.4])
cylinder(h=6.5,r=7);
translate([-13,-10,0])
cube([20,20,0.1]);
}
// barrel nut hole
translate([12,-22,-3])
cylinder(h=3.1, r1=3.8, r2=4);

}
// stepper-screw holes
translate([-15.5,-15.5,-1])
cylinder(h=10, r=1.6);
translate([-15.5,15.5,-1])
cylinder(h=10, r=1.6);
translate([15.5,15.5,-1])
cylinder(h=10, r=1.6);
translate([15.5,-15.5,-1])
cylinder(h=10, r=1.6);
// stepper-screw shoulder holes
translate([-15.5,-15.5,5])
cylinder(h=4, r=3.2);
translate([-15.5,15.5,5])
cylinder(h=4, r=3.2);
translate([15.5,15.5,5])
cylinder(h=4, r=3.2);
translate([15.5,-15.5,5])
cylinder(h=4, r=3.2);
// bearing hole
translate([0,0,-7.4])
cylinder(h=5.3,r=10.2/2);
// bearing inner-shoulder clearance
translate([0,0,-7.4])
cylinder(h=5.8,r=3.6);
// stepper axle hole
translate([0,0,-7.4])
cylinder(h=12,r=5.2/2);
}
translate([0,0,-6.4])
%bearing(model=425); // 5 x 10 x 4.2 - OpenBuilds small bearing
}

module spacer(){
difference(){
hull(){
translate([-20.1,17,0])
cylinder(h=5,r=1);
translate([-17,20.1,0])
cylinder(h=5,r=1);
translate([-17,-20.1,0])
cylinder(h=5,r=1);
translate([-20.1,-17,0])
cylinder(h=5,r=1);
translate([13,-22,0])
cylinder(h=5,r=7);
translate([15.5,15.5,0])
cylinder(h=5, r=5.6);
translate([22.7,13.6,0])
cylinder(h=5, r=1);
translate([22.7,-22.1,0])
cylinder(h=5, r=1);
}
translate([0,0,-1])
cylinder(h=7,r=12);
// stepper-screw holes
translate([-15.5,-15.5,-1])
cylinder(h=7, r=1.6);
translate([-15.5,15.5,-1])
cylinder(h=7, r=1.6);
translate([15.5,15.5,-1])
cylinder(h=7, r=1.6);
translate([15.5,-15.5,-1])
cylinder(h=7, r=1.6);
}
}

module spacertabs(){
difference(){
union(){
hull(){
translate([-20.1,17,0])
cylinder(h=5,r=1);
translate([-17,20.1,0])
cylinder(h=5,r=1);
translate([-17,-20.1,0])
cylinder(h=5,r=1);
translate([-20.1,-17,0])
cylinder(h=5,r=1);
translate([13,-22,0])
cylinder(h=5,r=7);
translate([15.5,15.5,0])
cylinder(h=5, r=5.6);
translate([22.7,13.6,0])
cylinder(h=5, r=1);
translate([22.7,-22.1,0])
cylinder(h=5, r=1);
}
hull(){
translate([-17,20.1,0])
cylinder(h=5,r=1);
translate([-17,-20.1,0])
cylinder(h=5,r=1);
translate([-22,20.1,0])
cylinder(h=5,r=1);
translate([-22,-20.1,0])
cylinder(h=5,r=1);
}
translate([-22.1,-21.1,-2])
cube([2.1,42.2,2.1]); // fillet body
hull(){
translate([-27,-30,4])
rotate([0,90,0])
cylinder(h=5,r=1);
translate([-27,-30,-14])
rotate([0,90,0])
cylinder(h=5,r=1);
translate([-27,-32,-1])
rotate([0,90,0])
cylinder(h=5,r=1);
translate([-27,-32,-9])
rotate([0,90,0])
cylinder(h=5,r=1);
translate([-27,30,4])
rotate([0,90,0])
cylinder(h=5,r=1);
translate([-27,30,-14])
rotate([0,90,0])
cylinder(h=5,r=1);
translate([-27,32,-1])
rotate([0,90,0])
cylinder(h=5,r=1);
translate([-27,32,-9])
rotate([0,90,0])
cylinder(h=5,r=1);
}
}
// stepper face
translate([0,0,-1])
cylinder(h=7,r=12);
// stepper-screw holes
translate([-15.5,-15.5,-1])
cylinder(h=7, r=1.6);
translate([-15.5,15.5,-1])
cylinder(h=7, r=1.6);
translate([15.5,15.5,-1])
cylinder(h=7, r=1.6);
translate([15.5,-15.5,-1])
cylinder(h=7, r=1.6);
// tab mounting holes
translate([-28,26.1,-5])
rotate([0,90,0])
cylinder(h=7,r=5.2/2);
translate([-28,-26.1,-5])
rotate([0,90,0])
cylinder(h=7,r=5.2/2);
// fillet
translate([-20,-21.1,-2])
rotate([-90,0,0])
cylinder(h=42.2,r=2);

}
}

module extruder(){

mount_plate_thickness = 10;  // thickness of material between stepper face and extruder
                     // set to 10 for mdf, set to 5 if using printed spacer
translate([0,0,-mount_plate_thickness])  // offset of stepper to allow for mount plate
%stepper_motor_mount(17);
translate([0,0,-mount_plate_thickness/2])
%cube([50,50,mount_plate_thickness],center=true); // plate between stepper and extruder
translate([0,0,2.35]) // [ adjust to line up with bearing ]
%hobbedgear(); // note: hobbed groove is untapped yet


// filament
translate([4.4,35,10])
rotate([90,0,0])
color("Blue")
%cylinder(h=65,r=0.9);

// press fit fitting
translate([4.4,14,10])
rotate([-90,0,0])
%pressfit();

// main base - centered at stepper axle
base();

// Lever assembly
translate([15.5,15.5,0.3])  // should be finish [15.5,15.5,0.3]
//rotate([0,0,90]) // comment out for closed position
lever();

// top cover
translate([0,0,20.5])
cover();

// thumb spring tension adjuster
//translate([21.1,0,0]) // comment out for closed position
//rotate(-45)           // comment out for closed position
//translate([-4,0,0])   // comment out for closed position
translate([26.8,-22.1,10])
rotate([0,90,0])
thumbspring();
}

/*  uncomment to see whole extruder alone - (this commented out to add to QXZ OpenBuilds folder)
extruder();

// barrel nut with screw
translate([12,-22,4])
//rotate(-45) // comment out for closed position
%barrelwscrew();
*/

// print spacer
//translate([0,0,-5.5])
//spacer();

// print spacer with mounting tabs
//translate([0,0,-5.5])
//spacertabs();


// print plastic barrel nut
//barrelnutprint();

// print topcover
//rotate([0,180,0]) cover();

// print base
//base();

// print lever
//rotate([0,90,0]) lever();

// print thumbspring
//thumbspring();